nxp-pac

Crates

git

Versions

mcxn947_cm33_core1

Flavors

Timing1

Struct Timing1 

#[repr(transparent)]
pub struct Timing1(pub u32);
Timing1

Tuple Fields

0: u32

Implementations

Source

impl Timing1

pub const fn taddr(&self) -> u8

Address to STROBE setup and hold time

pub const fn set_taddr(&mut self, val: u8)

Address to STROBE setup and hold time

pub const fn trelax(&self) -> u8

CSB, PGENB and LOAD to STROBE setup and hold time

pub const fn set_trelax(&mut self, val: u8)

CSB, PGENB and LOAD to STROBE setup and hold time

pub const fn trd(&self) -> u8

Read strobe pulse width time

pub const fn set_trd(&mut self, val: u8)

Read strobe pulse width time

pub const fn tps(&self) -> u8

PS to CSB setup and hold time between power switch and chip select assertion

pub const fn set_tps(&mut self, val: u8)

PS to CSB setup and hold time between power switch and chip select assertion

pub const fn tpd(&self) -> u8

PD to CSB setup time between power down signal deassertion and chip select signal assertion

pub const fn set_tpd(&mut self, val: u8)

PD to CSB setup time between power down signal deassertion and chip select signal assertion